==> melody_compiler-0.13.1.crate: melody_compiler-0.13.1/src/ast/error_messages.rs <==
use crate::errors::ParseError;

pub enum ErrorMessage {
    MissingRootNode,
    UnexpectedSpecialSymbolInQuantifier,
    UnexpectedQuantifierInQuantifier,
    UnexpectedAssertionInQuantifier,
    UnexpectedEmptyNodeInQuantifier,
    UnexpectedIdentifierForNonCaptureGroup,
    NegativeStartNotAllowed,
    NegativeEndNotAllowed,
    UninitializedVariable,
    UnexpectedVariableInvocationInQuantifier,
}

impl From<ErrorMessage> for ParseError {
    fn from(error: ErrorMessage) -> Self {
        let message = match error {
            ErrorMessage::MissingRootNode => "missing root node",
            ErrorMessage::UnexpectedSpecialSymbolInQuantifier => {
                "unexpected special symbol in quantifier"
            }
            ErrorMessage::UnexpectedQuantifierInQuantifier => "unexpected quantifier in quantifier",
            ErrorMessage::UnexpectedAssertionInQuantifier => "unexpected assertion in quantifier",
            ErrorMessage::UnexpectedEmptyNodeInQuantifier => "unexpected empty node in quantifier",
            ErrorMessage::UnexpectedVariableInvocationInQuantifier => {
                "unexpected variable invocation in quantifier"
            }
            ErrorMessage::UnexpectedIdentifierForNonCaptureGroup => {
                "unexpected identifier for non capture group"
            }
            ErrorMessage::NegativeStartNotAllowed => "negative start not allowed",
            ErrorMessage::NegativeEndNotAllowed => "negative end not allowed",
            ErrorMessage::UninitializedVariable => "usage of an uninitialized variable",
        };

        Self {
            message: String::from(message),
        }
    }
}

==> melody_compiler-0.13.5.crate: melody_compiler-0.13.5/src/ast/error_messages.rs <==
use crate::errors::ParseError;

pub enum ErrorMessage {
    CouldNotParseAnAmount,
    MissingNode,
    MissingRootNode,
    NegativeEndNotAllowed,
    NegativeStartNotAllowed,
    UnexpectedAssertionInQuantifier,
    UnexpectedEmptyNodeInQuantifier,
    UnexpectedIdentifierForNonCaptureGroup,
    UnexpectedQuantifierInQuantifier,
    UnexpectedSpecialSymbolInQuantifier,
    UnexpectedVariableInvocationInQuantifier,
    UninitializedVariable,
}

impl From<ErrorMessage> for ParseError {
    fn from(error: ErrorMessage) -> Self {
        let message = match error {
            ErrorMessage::CouldNotParseAnAmount => "could not parse an amount",
            ErrorMessage::MissingNode => "encountered a missing positional node",
            ErrorMessage::MissingRootNode => "missing root node",
            ErrorMessage::NegativeEndNotAllowed => "negative end not allowed",
            ErrorMessage::NegativeStartNotAllowed => "negative start not allowed",
            ErrorMessage::UnexpectedAssertionInQuantifier => "unexpected assertion in quantifier",
            ErrorMessage::UnexpectedEmptyNodeInQuantifier => "unexpected empty node in quantifier",
            ErrorMessage::UnexpectedIdentifierForNonCaptureGroup => {
                "unexpected identifier for non capture group"
            }
            ErrorMessage::UnexpectedQuantifierInQuantifier => "unexpected quantifier in quantifier",
            ErrorMessage::UnexpectedSpecialSymbolInQuantifier => {
                "unexpected special symbol in quantifier"
            }
            ErrorMessage::UnexpectedVariableInvocationInQuantifier => {
                "unexpected variable invocation in quantifier"
            }
            ErrorMessage::UninitializedVariable => "usage of an uninitialized variable",
        };

        Self {
            message: String::from(message),
        }
    }
}
